# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.convert_document_api import ConvertDocumentApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestConvertDocumentApi(unittest.TestCase):
    """ConvertDocumentApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.convert_document_api.ConvertDocumentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_convert_document_autodetect_to_pdf(self):
        """Test case for convert_document_autodetect_to_pdf

        Convert Document to PDF  # noqa: E501
        """
        pass

    def test_convert_document_docx_to_pdf(self):
        """Test case for convert_document_docx_to_pdf

        Word DOCX to PDF  # noqa: E501
        """
        pass

    def test_convert_document_pptx_to_pdf(self):
        """Test case for convert_document_pptx_to_pdf

        PowerPoint PPTX to PDF  # noqa: E501
        """
        pass

    def test_convert_document_xlsx_to_csv(self):
        """Test case for convert_document_xlsx_to_csv

        Excel XLSX to CSV  # noqa: E501
        """
        pass

    def test_convert_document_xlsx_to_pdf(self):
        """Test case for convert_document_xlsx_to_pdf

        Excel XLSX to PDF  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
