# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SetFormFieldValue(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_name': 'str',
        'text_value': 'str',
        'checkbox_value': 'bool',
        'combo_box_selected_index': 'int'
    }

    attribute_map = {
        'field_name': 'FieldName',
        'text_value': 'TextValue',
        'checkbox_value': 'CheckboxValue',
        'combo_box_selected_index': 'ComboBoxSelectedIndex'
    }

    def __init__(self, field_name=None, text_value=None, checkbox_value=None, combo_box_selected_index=None):  # noqa: E501
        """SetFormFieldValue - a model defined in Swagger"""  # noqa: E501

        self._field_name = None
        self._text_value = None
        self._checkbox_value = None
        self._combo_box_selected_index = None
        self.discriminator = None

        if field_name is not None:
            self.field_name = field_name
        if text_value is not None:
            self.text_value = text_value
        if checkbox_value is not None:
            self.checkbox_value = checkbox_value
        if combo_box_selected_index is not None:
            self.combo_box_selected_index = combo_box_selected_index

    @property
    def field_name(self):
        """Gets the field_name of this SetFormFieldValue.  # noqa: E501

        Name of the field to set; you can call /convert/edit/pdf/form/get-fields to enumerate field names in a form  # noqa: E501

        :return: The field_name of this SetFormFieldValue.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this SetFormFieldValue.

        Name of the field to set; you can call /convert/edit/pdf/form/get-fields to enumerate field names in a form  # noqa: E501

        :param field_name: The field_name of this SetFormFieldValue.  # noqa: E501
        :type: str
        """

        self._field_name = field_name

    @property
    def text_value(self):
        """Gets the text_value of this SetFormFieldValue.  # noqa: E501

        For fields of type Text, the text value to put into the field  # noqa: E501

        :return: The text_value of this SetFormFieldValue.  # noqa: E501
        :rtype: str
        """
        return self._text_value

    @text_value.setter
    def text_value(self, text_value):
        """Sets the text_value of this SetFormFieldValue.

        For fields of type Text, the text value to put into the field  # noqa: E501

        :param text_value: The text_value of this SetFormFieldValue.  # noqa: E501
        :type: str
        """

        self._text_value = text_value

    @property
    def checkbox_value(self):
        """Gets the checkbox_value of this SetFormFieldValue.  # noqa: E501

        For fields of type Checkbox, the value to put into the field  # noqa: E501

        :return: The checkbox_value of this SetFormFieldValue.  # noqa: E501
        :rtype: bool
        """
        return self._checkbox_value

    @checkbox_value.setter
    def checkbox_value(self, checkbox_value):
        """Sets the checkbox_value of this SetFormFieldValue.

        For fields of type Checkbox, the value to put into the field  # noqa: E501

        :param checkbox_value: The checkbox_value of this SetFormFieldValue.  # noqa: E501
        :type: bool
        """

        self._checkbox_value = checkbox_value

    @property
    def combo_box_selected_index(self):
        """Gets the combo_box_selected_index of this SetFormFieldValue.  # noqa: E501

        For fields of type ComboBox; specifies the selected index of the combo box selection  # noqa: E501

        :return: The combo_box_selected_index of this SetFormFieldValue.  # noqa: E501
        :rtype: int
        """
        return self._combo_box_selected_index

    @combo_box_selected_index.setter
    def combo_box_selected_index(self, combo_box_selected_index):
        """Sets the combo_box_selected_index of this SetFormFieldValue.

        For fields of type ComboBox; specifies the selected index of the combo box selection  # noqa: E501

        :param combo_box_selected_index: The combo_box_selected_index of this SetFormFieldValue.  # noqa: E501
        :type: int
        """

        self._combo_box_selected_index = combo_box_selected_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetFormFieldValue, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetFormFieldValue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
