# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.edit_pdf_api import EditPdfApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestEditPdfApi(unittest.TestCase):
    """EditPdfApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.edit_pdf_api.EditPdfApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_pdf_encrypt(self):
        """Test case for edit_pdf_encrypt

        Encrypt and password-protect a PDF  # noqa: E501
        """
        pass

    def test_edit_pdf_set_permissions(self):
        """Test case for edit_pdf_set_permissions

        Encrypt, password-protect and set restricted permissions on a PDF  # noqa: E501
        """
        pass

    def test_edit_pdf_watermark_text(self):
        """Test case for edit_pdf_watermark_text

        Add a text watermark to a PDF  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
