# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.models.pdf_form_fields import PdfFormFields  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestPdfFormFields(unittest.TestCase):
    """PdfFormFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPdfFormFields(self):
        """Test PdfFormFields"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cloudmersive_convert_api_client.models.pdf_form_fields.PdfFormFields()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
