# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.edit_text_api import EditTextApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestEditTextApi(unittest.TestCase):
    """EditTextApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.edit_text_api.EditTextApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_text_base64_decode(self):
        """Test case for edit_text_base64_decode

        Base 64 decode, convert base 64 string to binary content  # noqa: E501
        """
        pass

    def test_edit_text_base64_detect(self):
        """Test case for edit_text_base64_detect

        Detect, check if text string is base 64 encoded  # noqa: E501
        """
        pass

    def test_edit_text_base64_encode(self):
        """Test case for edit_text_base64_encode

        Base 64 encode, convert binary or file data to a text string  # noqa: E501
        """
        pass

    def test_edit_text_change_line_endings(self):
        """Test case for edit_text_change_line_endings

        Set, change line endings of a text file  # noqa: E501
        """
        pass

    def test_edit_text_detect_line_endings(self):
        """Test case for edit_text_detect_line_endings

        Detect line endings of a text file  # noqa: E501
        """
        pass

    def test_edit_text_remove_all_whitespace(self):
        """Test case for edit_text_remove_all_whitespace

        Remove whitespace from text string  # noqa: E501
        """
        pass

    def test_edit_text_remove_html(self):
        """Test case for edit_text_remove_html

        Remove HTML from text string  # noqa: E501
        """
        pass

    def test_edit_text_text_encoding_detect(self):
        """Test case for edit_text_text_encoding_detect

        Detect text encoding of file  # noqa: E501
        """
        pass

    def test_edit_text_trim_whitespace(self):
        """Test case for edit_text_trim_whitespace

        Trim leading and trailing whitespace from text string  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
